# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI for SDK

    The version of the OpenAPI document: 0.2.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.models.get_connections200_response_inner import GetConnections200ResponseInner

class TestGetConnections200ResponseInner(unittest.TestCase):
    """GetConnections200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetConnections200ResponseInner:
        """Test GetConnections200ResponseInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetConnections200ResponseInner`
        """
        model = GetConnections200ResponseInner()
        if include_optional:
            return GetConnections200ResponseInner(
                name = '',
                id = 56
            )
        else:
            return GetConnections200ResponseInner(
        )
        """

    def testGetConnections200ResponseInner(self):
        """Test GetConnections200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
