# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI for SDK

    The version of the OpenAPI document: 0.2.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.api.integrations_api import IntegrationsApi


class TestIntegrationsApi(unittest.TestCase):
    """IntegrationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IntegrationsApi()

    def tearDown(self) -> None:
        pass

    def test_get_connections(self) -> None:
        """Test case for get_connections

        List all connected accounts
        """
        pass

    def test_get_integration(self) -> None:
        """Test case for get_integration

        Retrieve a specific integration
        """
        pass

    def test_get_integrations(self) -> None:
        """Test case for get_integrations

        List all integrations
        """
        pass


if __name__ == '__main__':
    unittest.main()
