# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI for SDK

    The version of the OpenAPI document: 0.2.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.models.graph_ql_response_errors_inner import GraphQLResponseErrorsInner

class TestGraphQLResponseErrorsInner(unittest.TestCase):
    """GraphQLResponseErrorsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GraphQLResponseErrorsInner:
        """Test GraphQLResponseErrorsInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GraphQLResponseErrorsInner`
        """
        model = GraphQLResponseErrorsInner()
        if include_optional:
            return GraphQLResponseErrorsInner(
                message = '',
                locations = [
                    robotnikai.models.graph_ql_response_errors_inner_locations_inner.GraphQLResponse_errors_inner_locations_inner(
                        line = 56, 
                        column = 56, )
                    ],
                path = [
                    ''
                    ]
            )
        else:
            return GraphQLResponseErrorsInner(
        )
        """

    def testGraphQLResponseErrorsInner(self):
        """Test GraphQLResponseErrorsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
